@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim:et sts=4 sw=4
 #
 # ibus-table - The Tables engine for IBus
@@ -17,17 +16,30 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>
-
+'''
+Module to initialize gettext
+'''
 import locale
 import gettext
 import os
 
 DOMAINNAME = "ibus-table"
 
-_ = lambda a: gettext.dgettext(DOMAINNAME, a)
-N_ = lambda a: a
+def _(text: str) -> str:
+    '''Gettext translation function.'''
+    return gettext.dgettext(DOMAINNAME, text)
 
-def init():
+def N_(text: str) -> str: # pylint: disable=invalid-name
+    '''Mark string for translation without actually translating.
+
+    Used by gettext tools to extract strings that need translation.
+    '''
+    return text
+
+def init() -> None:
+    '''
+    Initialize gettext
+    '''
     localedir = os.getenv("IBUS_LOCALEDIR")
     # Python's locale module doesn't provide all methods on some
     # operating systems like FreeBSD
