@@ -124,7 +124,7 @@ def detect_chinese_category_old(phrase: str) -> int:
     try:
         tmp_phrase.encode('gb2312')
         category |= 1
-    except:
+    except Exception:
         if '〇' in tmp_phrase:
             # we add '〇' into SC as well
             category |= 1
@@ -132,7 +132,7 @@ def detect_chinese_category_old(phrase: str) -> int:
     try:
         tmp_phrase.encode('big5hkscs')
         category |= 1 << 1
-    except:
+    except Exception:
         # then check whether in gbk,
         if category & 1:
             # already know in SC
@@ -142,7 +142,7 @@ def detect_chinese_category_old(phrase: str) -> int:
             try:
                 tmp_phrase.encode('gbk')
                 category |= 1
-            except:
+            except Exception:
                 # not in gbk
                 pass
     # then set for 3rd bit, if not in SC and TC
@@ -359,7 +359,6 @@ TEST_DATA = {
     '沪': 3, # U+6CAA ...
     '戏': 3, # U+620F ...
     '浅': 3, # U+6D45 ...
-    '沪': 3, # U+6CAA ...
     '滨': 3, # U+6EE8 ...
     '劝': 3, # U+529D ...
     '沈': 3, # U+6C88 ...
@@ -628,7 +627,6 @@ TEST_DATA = {
     '莅': 3, # U+8385 ...
     '葱': 3, # U+8471 ...
     '并': 3, # U+5E76 ...
-    '荆': 3, # U+8346 ...
     '萝': 3, # U+841D ...
     '蔂': 3, # U+8502 ...
     '岁': 3, # U+5C81 ...
@@ -646,35 +644,6 @@ TEST_DATA = {
     '罗': 3, # U+7F57 ...
     '园': 3, # U+56ED ...
     '累': 3, # U+7D2F ...
-    '兑': 3, # U+5151 ...
-    '栀': 3, # U+6800 ...
-    '构': 3, # U+6784 ...
-    '双': 3, # U+53CC ...
-    '洒': 3, # U+6D12 ...
-    '滚': 3, # U+6EDA ...
-    '娄': 3, # U+5A04 ...
-    '壳': 3, # U+58F3 ...
-    '术': 3, # U+672F ...
-    '庐': 3, # U+5E90 ...
-    '义': 3, # U+4E49 ...
-    '郁': 3, # U+90C1 ...
-    '刹': 3, # U+5239 ...
-    '疴': 3, # U+75B4 ...
-    '压': 3, # U+538B ...
-    '历': 3, # U+5386 ...
-    '亏': 3, # U+4E8F ...
-    '随': 3, # U+968F ...
-    '内': 3, # U+5185 ...
-    '仪': 3, # U+4EEA ...
-    '气': 3, # U+6C14 ...
-    '掷': 3, # U+63B7 ...
-    '别': 3, # U+522B ...
-    '荣': 3, # U+8363 ...
-    '郑': 3, # U+90D1 ...
-    '并': 3, # U+5E76 ...
-    '萝': 3, # U+841D ...
-    '困': 3, # U+56F0 ...
-    '堕': 3, # U+5815 ...
     '头': 3, # U+5934 ...
     '欤': 3, # U+6B24 ...
     '逊': 3, # U+900A ...
@@ -700,16 +669,12 @@ TEST_DATA = {
     '适': 3, # U+9002 ...
     '弃': 3, # U+5F03 ...
     '斗': 3, # U+6597 ...
-    '头': 3, # U+5934 ...
     '刘': 3, # U+5218 ...
     '斋': 3, # U+658B ...
     '边': 3, # U+8FB9 ...
     '还': 3, # U+8FD8 ...
     '远': 3, # U+8FDC ...
-    '欤': 3, # U+6B24 ...
-    '逊': 3, # U+900A ...
     '迩': 3, # U+8FE9 ...
-    '点': 3, # U+70B9 ...
     '战': 3, # U+6218 ...
     '逻': 3, # U+903B ...
     '禀': 3, # U+7980 ...
